@@ -48,7 +48,15 @@ class IUser( IEqual ) :
         """ User ( str ).
         """
 
-        return getpass.getuser( )
+        try :
+
+            value = getpass.getuser( )
+
+        except :
+
+            value = ''
+
+        return value
 
     def __eq__( self, other : any ) -> bool :
 
@@ -56,11 +64,11 @@ class IUser( IEqual ) :
 
             Arguments :
 
-                other - Other object ( object ).
+                other - Other ( any ).
 
             Returns :
 
-                equality - Equality condition ( bool ).
+                equality - Equality ( bool ).
         """
 
         return ( ( super( ).__eq__( other ) ) and ( self.user == other.user ) )
