@@ -5,6 +5,7 @@ from .IClear import IClear
 from .ICompress import ICompress
 from .IConfigure import IConfigure
 from .IConnect import IConnect
+from .ICount import ICount
 from .IData import IData
 from .IDate import IDate
 from .IDispose import IDispose
@@ -16,6 +17,7 @@ from .IFrequency import IFrequency
 from .IIdentity import IIdentity
 from .IInterval import IInterval
 from .ILatency import ILatency
+from .IModel import IModel
 from .IPath import IPath
 from .IPeriod import IPeriod
 from .IPhase import IPhase
@@ -26,7 +28,6 @@ from .IReset import IReset
 from .IResolution import IResolution
 from .IRotation import IRotation
 from .IS import IS
-from .IState import IState
 from .IStream import IStream
 from .ITimeZone import ITimeZone
 from .IUpdate import IUpdate
